@@ -103,6 +103,11 @@
 /* hardware rendering is an option? */
 #define DXD_CAN_HAVE_HW_RENDERING 1
 
+#if defined(HAVE_LIBGL) || defined(HAVE_LIBGLWSTATI)
+/* is hardware sensitive to vertex orientation of 1st triangle in strip? */
+#define DXD_HW_TMESH_ORIENT_SENSITIVE 1
+#endif
+
 /* supports full IEEE standard floating point, including under/overflow */
 #define DXD_STANDARD_IEEE 1
 
@@ -387,9 +392,6 @@ char *strrstr(char *, char *);
 /* can you use rlimit to stop the exec from creating a huge core file? */
 #define DXD_HAS_RLIMIT 1
 
-/* is hardware sensitive to vertex orientation of 1st triangle in strip? */
-#define DXD_HW_TMESH_ORIENT_SENSITIVE 1
-
 /* Does the X server behave correctly for a move of a XGL window */
 #define DXD_HW_XSERVER_MOVE_OK 1
 
@@ -445,9 +447,6 @@ char *strrstr(char *, char *);
 /* can you use rlimit to stop the exec from creating a huge core file? */
 #define DXD_HAS_RLIMIT 1
 
-/* is hardware sensitive to vertex orientation of 1st triangle in strip? */
-#define DXD_HW_TMESH_ORIENT_SENSITIVE 1
- 
 /* can use the crypt system call for data encryption */
 #define DXD_HAS_CRYPT  1
 
@@ -546,7 +545,7 @@ union wait{
 
 #undef IOCTL
 #define IOCTL(fd,cmd,buf) \
-	 ioctlsocket(fd,cmd,(char *)buf)
+	 ioctlsocket(fd,cmd,(u_long *)buf)
 
 
 #if defined(DXD_EXEC_WAIT_PROCESS)
@@ -585,6 +584,7 @@ union wait{
 #define MAXPATHLEN           255
 
 #define DXD_SOCKET_WINSOCKETS_OK 1
+#define socklen_t int 
 
 /* to port directories on PC enviroments     */
 #define DXD_NON_UNIX_DIR_SEPARATOR 1
@@ -593,7 +593,6 @@ union wait{
 /* #define	_WINERROR_ 1 */
 /* #define _DLGSH_INCLUDED_  1  */
 
-#include <windows.h>
 #include <errno.h>
 
 /* do you need to declare the system error list explicitly? */
@@ -642,8 +641,14 @@ union wait{
 #include <process.h>
 #include <direct.h>
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
 int gettablesize(void);
 int getopt(int,char**,char*);
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
 
 #if defined(cygwin)
 #include <sys/types.h>
@@ -664,7 +669,7 @@ int getopt(int,char**,char*);
 
 
 #define wait(status)  cwait(status, status, 0)        
-#define trunc(value) ((float)((int)(value)))
+#define trunc(value) ((double)((int)(value)))
 #define rint(value) ((float)((int)((value) + 0.5)))       
 
 #endif  /*   intelnt  */
