@@ -6,7 +6,7 @@
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
 /*
- * $Header: /src/master/dx/src/exec/dpexec/_macro.h,v 1.5 2000/08/11 15:28:08 davidt Exp $
+ * $Header: /src/master/dx/src/exec/dpexec/_macro.h,v 1.6 2004/06/09 16:14:27 davidt Exp $
  */
 
 #include <dxconfig.h>
@@ -26,6 +26,10 @@ number of inputs and their names and number of outputs and their names.
 
 #include "d.h"
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 Error	_dxf_ExMacroInit	(void);
 int	_dxf_ExMacroInsert	(char *name, EXObj obj);
 int	_dxf_ExMacroDelete	(char *name);
@@ -33,4 +37,8 @@ EXObj	_dxf_ExMacroSearch	(char *name);
 
 extern	EXDictionary	_dxd_exMacroDict; /* defined in macro.c */
 
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
+
 #endif /* __MACRO_H */
