@@ -5,5 +5,5 @@
 /* This code licensed under the                                        */
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
-#define EX_COM_DATE "Tue Aug 19 18:38:19 MDT 2003"
-#define EX_COM_HOST "Darwin localhost 6.6 Darwin Kernel Version 6.6: Thu May 1 21:48:54 PDT 2003; root:xnu/xnu-344.34.obj~1/RELEASE_PPC Power Macintosh powerpc"
+#define EX_COM_DATE "Mon Jan 9 16:39:11 MST 2006"
+#define EX_COM_HOST "Darwin beaverhead 8.3.0 Darwin Kernel Version 8.3.0: Mon Oct 3 20:04:04 PDT 2005; root:xnu-792.6.22.obj~2/RELEASE_PPC Power Macintosh powerpc"
