@@ -6,7 +6,7 @@
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
 /*
- * $Header: /src/master/dx/src/exec/dpexec/nodeb.h,v 1.2 2000/08/11 15:28:12 davidt Exp $
+ * $Header: /src/master/dx/src/exec/dpexec/nodeb.h,v 1.3 2004/06/09 16:14:28 davidt Exp $
  */
 
 #ifndef _NODEB_H
@@ -14,7 +14,15 @@
 
 #include "parse.h"
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 int _dxf_ExWriteTree(struct node *pt, int fd);
 struct node *_dxf_ExReadTree(int fd, int swap);
 
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
+
 #endif /* _NODEWRITEB_H */
