@@ -8,12 +8,12 @@
 #define ARRWPTS 6 
 #define ARRWLNS 5 
 static Point points[ARRWPTS] = {
- {  0.0000000000,      0.0000000000,      0.0000000000 }, 
- {  0.0000000000,      1.0000000000,      0.0000000000 }, 
- { -0.2500000000,      0.8000000000,     -0.2500000000 }, 
- { -0.2500000000,      0.8000000000,      0.2500000000 }, 
- {  0.2500000000,      0.8000000000,     -0.2500000000 }, 
- {  0.2500000000,      0.8000000000,      0.2500000000 }, 
+ {  0.0000000000F,      0.0000000000F,      0.0000000000F }, 
+ {  0.0000000000F,      1.0000000000F,      0.0000000000F }, 
+ { -0.2500000000F,      0.8000000000F,     -0.2500000000F }, 
+ { -0.2500000000F,      0.8000000000F,      0.2500000000F }, 
+ {  0.2500000000F,      0.8000000000F,     -0.2500000000F }, 
+ {  0.2500000000F,      0.8000000000F,      0.2500000000F }, 
 };
 
 #include <dxconfig.h>
