@@ -12,13 +12,13 @@
 
 
 static Point points[RCKT2DPTS] = {
- {  0.2000000000,      0.0000000000,    0.0 },
- { -0.2000000000,      0.0000000000,    0.0 }, 
- {  0.2000000000,      0.7000000000,    0.0 },  
- { -0.2000000000,      0.7000000000,    0.0 },  
- {  0.6000000000,      0.7000000000,    0.0 },  
- { -0.6000000000,      0.7000000000,    0.0 },  
- {  0.0000000000,      1.0000000000,    0.0 }
+ {  0.2000000000F,      0.0000000000F,    0.0F },
+ { -0.2000000000F,      0.0000000000F,    0.0F }, 
+ {  0.2000000000F,      0.7000000000F,    0.0F },  
+ { -0.2000000000F,      0.7000000000F,    0.0F },  
+ {  0.6000000000F,      0.7000000000F,    0.0F },  
+ { -0.6000000000F,      0.7000000000F,    0.0F },  
+ {  0.0000000000F,      1.0000000000F,    0.0F }
 };
    
 static Triangle triangles[] = {
