@@ -8,7 +8,9 @@
 
 #include <dxconfig.h>
 
-
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
 
 #include <dx/dx.h>
 
@@ -939,7 +941,7 @@ omitnamedgroup(Group g, Object names)
 	    if (!omitted)
 		goto error;
         
-	    if (!strcmp(membername, cp))
+	    if (cp && !strcmp(membername, cp))
 		continue;
 	    
 	    if (!DXSetMember(newg, cp, omitted))
