@@ -13,6 +13,14 @@
  * $Source: /src/master/dx/src/exec/hwrender/hwTmesh.c,v $
  */
 
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
+
+#if defined(HAVE_STRINGS_H)
+#include <strings.h>
+#endif
+
 #include <stdio.h>
 #include "hwDeclarations.h"
 #include "hwXfield.h"
@@ -22,6 +30,9 @@
 
 #include "hwDebug.h"
 
+extern dxObject _dxf_QueryObject(HashTable, dxObject);
+extern void _dxf_InsertObject(HashTable, dxObject, dxObject);
+
 typedef struct _Triple
 {
   int p[3] ;
