@@ -8,7 +8,13 @@
 
 #include <dxconfig.h>
 
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
 
+#if defined(HAVE_STRINGS_H)
+#include <strings.h>
+#endif
 
 #include "hwDeclarations.h"
 #include "hwXfield.h"
@@ -120,6 +126,12 @@ static Error _gammaCorrectColors(xfieldP xf, double gamma, int isLit);
 /*=====================================================================*\
   Xfield component functions
 \*=====================================================================*/
+extern Error _dxfTriangulateField(Field);
+extern Error _dxf_XNeighbors(Field f, xfieldT *xf, enum xr required, enum xd xd);
+extern Error _dxf_linesToPlines (xfieldT *xf);
+extern Error _dxf_linesToPlines (xfieldT *xf);
+extern Error _dxf_trisToTmesh (xfieldT *xf, tdmChildGlobalP globals);
+extern Error _dxf_quadsToQmesh (xfieldT *xf, void *globals);
 
 /*
  * box, points, connections
@@ -176,7 +188,7 @@ _XPositions(Field f, xfieldT* xf, enum xr required)
   get(positions);
   DXGetArrayInfo(xf->positions_array,NULL,NULL,NULL,NULL,&xf->shape);
 
-  if (DXGetComponentValue(f, INVALID_POSITIONS))
+  if (DXGetComponentValue(f, INVALID_POSITIONS)) {
     /* This also creates DXReference() */
     if((xf->invPositions = DXCreateInvalidComponentHandle((dxObject)f,
 							  NULL,
@@ -185,6 +197,7 @@ _XPositions(Field f, xfieldT* xf, enum xr required)
       EXIT(("ERROR"));
       return ERROR;
     }
+  }
 
   EXIT(("OK"));
   return OK;
@@ -231,12 +244,12 @@ _XConnections(Field f, xfieldT* xf, enum xr required)
 	int volume;	/* whether these are volume connections */
 	int posPerConn;	/* positions per connection */
     } info[] = {
-	"lines",	ct_lines,	2,	0,	2,
-	"triangles",	ct_triangles,	3,	0,	3,
-	"quads",	ct_quads,	4,	0,	4,
-	"tetrahedra",	ct_tetrahedra,	4,	1,	3,
-	"cubes",	ct_cubes,	8,	1,	4,
-	NULL
+	{ "lines",	ct_lines,	2,	0,	2 },
+	{ "triangles",	ct_triangles,	3,	0,	3 },
+	{ "quads",	ct_quads,	4,	0,	4 },
+	{ "tetrahedra",	ct_tetrahedra,	4,	1,	3 },
+	{ "cubes",	ct_cubes,	8,	1,	4} ,
+	{ NULL }
     };
     struct info *i;
     dxObject cto;
@@ -356,7 +369,7 @@ _XColors(Field f, xfieldT* xf,
 	     enum xr required)
 {
   Array colors_array;
-  char *fs, *bs, *s;
+  char *fs, *bs, *s = NULL;
   dependencyT color_dep;
   int		ncolors;
   
@@ -626,6 +639,7 @@ _XOpacities(Field f, xfieldT* xf,
 }
 
 
+/*
 static Error
 _XFreeLocal(xfieldT* xf)
 {
@@ -633,6 +647,7 @@ _XFreeLocal(xfieldT* xf)
   EXIT(("stub function"));
   return OK;
 }
+*/
 
 
 /*=====================================================================*\
@@ -933,7 +948,7 @@ on an MP machine.
       char*	gammaStr;
 
       
-      if (gammaStr = (char*)getenv("DXHWGAMMA"))	{
+      if ( (gammaStr = (char*)getenv("DXHWGAMMA")) ) {
 	  gamma = atof(gammaStr);
 	  if (gamma < 0.0) gamma = 0.0;
 	}
@@ -1290,7 +1305,7 @@ _dxf_parameters(dxObject o, attributeP old)
   }
 
   /* get approximation density */
-  if ((options = DXGetAttribute(o, "render every")))
+  if ((options = DXGetAttribute(o, "render every"))) {
     if (DXExtractInteger (options, &density)) {
       new->buttonDown.density = density;
       new->buttonUp.density = density;
@@ -1304,6 +1319,7 @@ _dxf_parameters(dxObject o, attributeP old)
       EXIT(("ERROR"));
       DXErrorReturn(ERROR_BAD_PARAMETER,"#13360");
     }
+  }
   
   EXIT(("new = 0x%x", new));
   return new;
