@@ -12,7 +12,7 @@
 #ifndef HELPERCODE
 
 /*---------------------------------------------------------------------------*\
-$Header: /src/master/dx/src/exec/hwrender/opengl/hwPortUtilOGL.c,v 1.13 2003/09/30 17:41:45 davidt Exp $
+$Header: /src/master/dx/src/exec/hwrender/opengl/hwPortUtilOGL.c,v 1.16 2006/01/04 22:00:53 davidt Exp $
 
 Author:  Ellen Ball
 
@@ -23,6 +23,12 @@ Based on hwrender/gl/hwPortUtil.c
 #include <math.h>
 #include <string.h>
 
+#include "../hwDebug.h"
+
+#ifdef TIMER
+#undef TIMER
+#endif
+
 #ifdef DEBUG
 #define TIMER(s) glFlush(); DXMarkTime(s);
 #else
@@ -38,8 +44,6 @@ Based on hwrender/gl/hwPortUtil.c
 #include "hwPortOGL.h"
 
 
-#include "../hwDebug.h"
-
 #if defined(HAVE_WINDOWS_H)
 #include <windows.h>
 #endif
@@ -474,7 +478,7 @@ static Error points (xfieldP xf, helperFunc helper,
   static long	iscratch;
   int		i = 0, c;
   dependencyT   odep;
-  int 		translu;
+  int 		translu = 0;
 
   ENTRY(("points (0x%x, 0x%x, %d, %d, %d, %d, %d)",
 	 xf, helper, firstConnection, lastConnection, face, approx, skip));
@@ -608,7 +612,7 @@ static Error lines (xfieldP xf, helperFunc helper,
   static int	iscratch;
   int		c;
   dependencyT   odep;
-  int 		translu;
+  int 		translu = 0;
 
   ENTRY(("lines (0x%x, 0x%x, %d, %d, %d, %d, %d)",
 	 xf, helper, firstConnection, lastConnection, face, approx, skip));
@@ -1165,7 +1169,7 @@ static Error polylines (xfieldP xf, helperFunc helper,
     static float fscratch[3];
     static int	 iscratch;
     int		 c;
-    int	         start, end, knt, max, thisknt;
+    int	         start, end, knt, max = 0, thisknt;
 
     if(approx == approx_box)
     {
@@ -1447,8 +1451,8 @@ _drawPrimitives(tdmPortHandleP portHandle, xfieldP xf,
 
     if(xf->attributes.aalines) {
        glEnable(GL_LINE_SMOOTH);
-       glEnable(GL_BLEND);
-       glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+       //glEnable(GL_BLEND);
+       //glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
        glHint(GL_LINE_SMOOTH_HINT, GL_DONT_CARE);
     }
     helper = getHelper(xf->colorsDep,dep_none,dep_none,xf->texture != NULL);
@@ -1456,7 +1460,7 @@ _drawPrimitives(tdmPortHandleP portHandle, xfieldP xf,
     lines(xf,helper,0,xf->nconnections,0,approx,density) ;
     TIMER("< lines") ;
     glDisable(GL_LINE_SMOOTH);
-    glDisable(GL_BLEND);
+    //glDisable(GL_BLEND);
     break;
   case ct_polylines:
      PRINT(("> polylines"));
@@ -1465,8 +1469,8 @@ _drawPrimitives(tdmPortHandleP portHandle, xfieldP xf,
 
      if(xf->attributes.aalines) {
         glEnable(GL_LINE_SMOOTH);
-        glEnable(GL_BLEND);
-        glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+        //glEnable(GL_BLEND);
+        //glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
         glHint(GL_LINE_SMOOTH_HINT, GL_DONT_CARE);
      }
      helper = getHelper(xf->colorsDep, dep_none, dep_none, 0);
@@ -1474,7 +1478,7 @@ _drawPrimitives(tdmPortHandleP portHandle, xfieldP xf,
      polylines(xf, helper, approx, density);
      TIMER("< polylines");
      glDisable(GL_LINE_SMOOTH);
-     glDisable(GL_BLEND);
+     //glDisable(GL_BLEND);
      break;
   case ct_pline:
      PRINT((" plines:"));
@@ -1483,8 +1487,8 @@ _drawPrimitives(tdmPortHandleP portHandle, xfieldP xf,
 
      if(xf->attributes.aalines) {
         glEnable(GL_LINE_SMOOTH);
-        glEnable(GL_BLEND);
-        glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+        //glEnable(GL_BLEND);
+        //glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
         glHint(GL_LINE_SMOOTH_HINT, GL_DONT_CARE);
      }
      helper = getHelper(xf->colorsDep,dep_none,dep_none, xf->texture != NULL);
@@ -1492,7 +1496,7 @@ _drawPrimitives(tdmPortHandleP portHandle, xfieldP xf,
      plines(xf,helper,approx,density);
      TIMER("< plines");
      glDisable(GL_LINE_SMOOTH);
-     glDisable(GL_BLEND);
+     //glDisable(GL_BLEND);
      break;
   case ct_triangles: 
      PRINT((" tris:"));
@@ -1604,12 +1608,12 @@ Error _dxf_DrawTranslucentOGL(void *globals,
   ENTRY(("_dxf_DrawTranslucentOGL(0x%x, 0x%x, 0x%x, 0x%x)",
          PORT_HANDLE, xf, ambientColor, buttonUp));
 
-  glEnable(GL_BLEND);
-  OGL_FAIL_ON_ERROR(glEnableBlend);
-  glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-  OGL_FAIL_ON_ERROR(glBlendFunc);
-  glAlphaFunc(GL_GREATER, 0.0);
-  OGL_FAIL_ON_ERROR(glAlphaFunc);
+  //glEnable(GL_BLEND);
+  //OGL_FAIL_ON_ERROR(glEnableBlend);
+  //glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+  //OGL_FAIL_ON_ERROR(glBlendFunc);
+  //glAlphaFunc(GL_GREATER, 0.0);
+  //OGL_FAIL_ON_ERROR(glAlphaFunc);
 
   for (i = 0; i < nSorted; i = j)
   {
@@ -1730,9 +1734,9 @@ Error _dxf_DrawTranslucentOGL(void *globals,
 
    }
 
-   glDisable(GL_BLEND);
+   //glDisable(GL_BLEND);
 
-   OGL_FAIL_ON_ERROR(_dxf_DrawTranslucentOGL);
+   //OGL_FAIL_ON_ERROR(_dxf_DrawTranslucentOGL);
    glFinish();
    EXIT(("OK"));
    return OK;
@@ -1744,7 +1748,7 @@ Error _dxf_DrawTranslucentOGL(void *globals,
       glCallList(notFirstPass + 1);
 #endif
 
-   glDisable(GL_BLEND);
+   //glDisable(GL_BLEND);
 
 
    _dxf_SET_GLOBAL_LIGHT_ATTRIBUTES(PORT_CTX ,0) ;
