@@ -78,6 +78,7 @@
 #if defined(macos)
 #include <mach/mach.h>
 #include <sys/param.h>
+extern mach_port_t host_self(void);
 #endif
 
 #if DXD_HAS_RLIMIT && ! DXD_IS_MP
@@ -87,7 +88,6 @@
 
 extern int _dxd_exRemoteSlave;
 extern void _dxfemergency(void);
-extern int _dxfPhysicalProcs(void);
 
 /*
  * Every memory block starts with a struct block.  The user's portion
@@ -368,6 +368,8 @@ static void insfree(struct list *, struct block *);
 static Error aprint(struct arena *a, int how, struct printvals *v);
 static Error acheck(struct arena *a);
 
+int _dxf_GetPhysicalProcs();
+
 static Error
 expand(struct arena *a, ulong n)
 {
@@ -1213,7 +1215,49 @@ getProcMemInfo()
 
 #endif
 
-#if defined(intelnt) || defined(WIN32)
+/* cygwin: 
+   to obtain available memory size in cygwin, the standard method seems to  
+   be sysconf(), but it doesn't work in Win98.  Instead, we use WIN32 way.  
+   notes: 
+   (1) GlobalMemoryStatus() reports a rather small value as *available*  
+   physical memory (11MB or so); we don't use that value.   
+   (2) cygwin has 384MB limit by default.  See cygwin User's Guide.   
+*/ 
+  
+#ifdef cygwin 
+/* include <windows.h> causes errors; put minimum defs here for memory api */ 
+#define WINAPI __stdcall 
+#define FALSE 0 
+#define MEM_FREE            0x10000 
+typedef void VOID; 
+typedef void *PVOID; 
+typedef const void *LPCVOID; 
+typedef unsigned long DWORD; 
+typedef unsigned long ULONG; 
+typedef struct _MEMORY_BASIC_INFORMATION { 
+       PVOID BaseAddress; 
+       PVOID AllocationBase; 
+       DWORD AllocationProtect; 
+       DWORD RegionSize; 
+       DWORD State; 
+       DWORD Protect; 
+       DWORD Type; 
+} MEMORY_BASIC_INFORMATION,*PMEMORY_BASIC_INFORMATION; 
+typedef struct _MEMORYSTATUS { 
+       DWORD dwLength; 
+       DWORD dwMemoryLoad; 
+       DWORD dwTotalPhys; 
+       DWORD dwAvailPhys; 
+       DWORD dwTotalPageFile; 
+       DWORD dwAvailPageFile; 
+       DWORD dwTotalVirtual; 
+       DWORD dwAvailVirtual; 
+} MEMORYSTATUS,*LPMEMORYSTATUS; 
+DWORD WINAPI VirtualQuery(LPCVOID,PMEMORY_BASIC_INFORMATION,DWORD); 
+VOID WINAPI GlobalMemoryStatus(LPMEMORYSTATUS); 
+#endif 
+
+#if defined(intelnt) || defined(WIN32) || defined(cygwin)
 Error _dxfLocateFreeMemory (ulong *size) {
 	/* Basically with Windows we need to walk the memory tree to locate
 	   a range of free addresses that are left in the 2GB address
@@ -1287,7 +1331,7 @@ int _dxf_initmemory(void)
      * before we overflow 32bit ints.  seems safe for now.
      */
 
-#if defined(intelnt) || defined(WIN32)
+#if defined(intelnt) || defined(WIN32) || defined(cygwin)
 	if(total_size) {
 		ULONG avail;
 
@@ -1369,7 +1413,7 @@ int _dxf_initmemory(void)
 	physmem = 32;
 #endif
 
-#if defined(intelnt) || defined(WIN32)
+#if defined(intelnt) || defined(WIN32) || defined(cygwin)
 	{
 		MEMORYSTATUS memStatus;
 		ULONG avail;
@@ -1381,7 +1425,7 @@ int _dxf_initmemory(void)
 		if(memStatus.dwTotalPhys > 0)
 			physmem = memStatus.dwTotalPhys;
 		else /* Whoa boy big memory - limit to 4GB*/
-			physmem = 4294967295;
+			physmem = 4294967295U;
 		
 		_dxfLocateFreeMemory(&avail);
 		if(avail < physmem) physmem = avail;
@@ -1491,8 +1535,8 @@ int _dxf_initmemory(void)
 	if (getenv("DX_DEBUG_MEMORY_INIT")) {
 	    char buf[132];
 	    
-	    sprintf(buf, "initial: physmem %d, othermem %d, po_ratio %g, physproc %d, nproc %d\n",
-		    physmem, othermem, po_ratio, _dxfPhysicalProcs(), DXProcessors(0));
+	    sprintf(buf, "initial: physmem %d, othermem %d, po_ratio %g, physical procs %d, nproc %d\n",
+		    physmem, othermem, po_ratio, _dxf_GetPhysicalProcs(), DXProcessors(0));
 	    write(2, buf, strlen(buf));
 	}
 #endif
@@ -1501,14 +1545,14 @@ int _dxf_initmemory(void)
 	/* if this is an MP machine, make the default be to leave 2/3 of the
 	 * memory on the machine available to other tasks.
 	 */
-	if (_dxfPhysicalProcs() > 1)
+	if (_dxf_GetPhysicalProcs() > 1)
 	    othermem = (uint)(physmem * 0.66);
 #else
 	/* if this is an MP machine, leave up to 5/8 of physical memory free
          * for other processes.
 	 */
-	if (_dxfPhysicalProcs() > 1)
-	    po_ratio = MIN(5.0, (float)_dxfPhysicalProcs()) / 8.0;
+	if (_dxf_GetPhysicalProcs() > 1)
+	    po_ratio = MIN(5.0, (float)_dxf_GetPhysicalProcs()) / 8.0;
 #endif
 
 	/* allow for the fact that on all systems but pvs, there are other
@@ -2311,3 +2355,40 @@ DXMaxFreedBlock()
 {
     return maxFreedBlock;
 }
+
+
+int _dxf_GetPhysicalProcs()
+{
+	/* return the number of physical processors on the system.
+	*  this is different from the number of processes the user
+	*  asked us to use with -pN
+	*/
+
+	int nphysprocs = 0;
+
+#if defined(linux) && (ENABLE_SMP_LINUX == 0)
+    nphysprocs = 1;
+
+#elif HAVE_SYSMP
+    nphysprocs = sysmp (MP_NPROCS);	/* find the number of processors */
+
+#elif DXD_HAS_LIBIOP
+    nphysprocs = nprocs = SVS_n_cpus;
+
+#elif HAVE_SYSCONF && defined(_SC_NPROCESSORS_ONLN)
+    nphysprocs = sysconf(_SC_NPROCESSORS_ONLN);
+
+#elif HAVE_SYS_SYSCONFIG_NCPUS
+    nphysprocs = _system_configuration.ncpus; /* In Kernel space */
+
+#elif defined(intelnt) || defined(WIN32)
+    SYSTEM_INFO sysinfo;
+	GetSystemInfo(&sysinfo);
+	nphysprocs = sysinfo.dwNumberOfProcessors;
+#else
+    nphysprocs = 1;
+#endif
+
+    return nphysprocs;
+}
+
