@@ -9,14 +9,14 @@
 
 #include "dx.h"
 
-#if !defined(intelnt) && !defined(cygwin) && !defined(WIN32)
+#if !defined(intelnt) && !defined(WIN32)
 #include <stdio.h>
-int main(){fprintf(stderr, "misc/dx is only needed on Windows based systems.\n"); return 1;}
+int main(){fprintf(stderr, "misc/dx is only needed on Windows (non-cygwin) based systems.\n"); return 1;}
 #else /* Windows system compile application */
 
 #include "utils.h"
 
-/* #define USE_REGISTRY 1 */
+#define USE_REGISTRY 1
 
 #if defined(cygwin)
 void
@@ -78,7 +78,7 @@ smallstr 	exread =	"";
 smallstr 	uitime =	"";
 smallstr 	extime =	"";
 smallstr 	uihilite =	"";
-smallstr 	exhilite =	"";
+smallstr 	exhilite =	"-B"; /* Default is on */
 namestr 	FileName =	"";
 namestr 	dxroot =	"";
 namestr 	dxexroot =	"";
@@ -177,20 +177,34 @@ int regval(enum regGet get, char *name, enum regCo co, char *value, int size, in
     REGSAM access = KEY_READ;
     const char **regpath;
     const char *dxpath[] = {"SOFTWARE\\OpenDX\\DX\\CurrentVersion", NULL };
-    const char *snpath[] = { "SOFTWARE\\Starnet\\X-Win32\\5.5", 
-			     "SOFTWARE\\Starnet\\X-Win32\\5.4",
-			     "SOFTWARE\\Starnet\\X-Win32\\5.3",
-			     "SOFTWARE\\Starnet\\X-Win32\\5.2",
-			     "SOFTWARE\\Starnet\\X-Win32\\5.1", NULL };
+    const char *snpath[] = { "SOFTWARE\\Starnet\\X-Win32 LX\\7.1",
+		"SOFTWARE\\Starnet\\X-Win32 LX\\7.0",
+		"SOFTWARE\\Starnet\\X-Win32 LX\\6.1",
+		"SOFTWARE\\Starnet\\X-Win32 LX\\6.0",
+		"SOFTWARE\\Starnet\\X-Win32\\7.1",
+		"SOFTWARE\\Starnet\\X-Win32\\7.0",
+		"SOFTWARE\\Starnet\\X-Win32\\6.2",
+		"SOFTWARE\\Starnet\\X-Win32\\6.1",
+		"SOFTWARE\\Starnet\\X-Win32\\6.0",
+		"SOFTWARE\\Starnet\\X-Win32\\5.5", 
+		"SOFTWARE\\Starnet\\X-Win32\\5.4",
+		"SOFTWARE\\Starnet\\X-Win32\\5.3",
+		"SOFTWARE\\Starnet\\X-Win32\\5.2",
+		"SOFTWARE\\Starnet\\X-Win32\\5.1", NULL };
     const char *wapath[] = { "SOFTWARE\\LabF.com\\WinaXe\\6.5",
 			     "SOFTWARE\\LabF.com\\WinaXe\\6.4",
 			     "SOFTWARE\\LabF.com\\WinaXe\\6.3",
 			     "SOFTWARE\\LabF.com\\WinaXe\\6.2",
 			     "SOFTWARE\\LabF.com\\WinaXe\\6.1", NULL };
-    const char *hbpath[] = { "SOFTWARE\\Hummingbird\\Connectivity\\8.10\\Exceed",
-			     "SOFTWARE\\Hummingbird\\Connectivity\\8.00\\Exceed",
-			     "SOFTWARE\\Hummingbird\\Connectivity\\7.10\\Exceed",
-			     "SOFTWARE\\Hummingbird\\Connectivity\\7.00\\Exceed", NULL };
+    const char *hbpath[] = { "SOFTWARE\\Hummingbird\\Connectivity\\11.00\\Exceed",
+		"SOFTWARE\\Hummingbird\\Connectivity\\10.10\\Exceed",
+		"SOFTWARE\\Hummingbird\\Connectivity\\10.00\\Exceed",
+		"SOFTWARE\\Hummingbird\\Connectivity\\9.10\\Exceed",
+		"SOFTWARE\\Hummingbird\\Connectivity\\9.00\\Exceed",
+		"SOFTWARE\\Hummingbird\\Connectivity\\8.10\\Exceed",
+		"SOFTWARE\\Hummingbird\\Connectivity\\8.00\\Exceed",
+		"SOFTWARE\\Hummingbird\\Connectivity\\7.10\\Exceed",
+		"SOFTWARE\\Hummingbird\\Connectivity\\7.00\\Exceed", NULL };
     const char *h6path[] = { "SOFTWARE\\Hummingbird\\Exceed\\CurrentVersion", NULL };
 
 	/* First determine which system we're looking up. */
@@ -418,7 +432,7 @@ int initrun()
     strcat(dxdata,"samples\\data");
 #endif
 
-/* Append the default dxroot/samples/macros to current macros */
+/* Append the default dxroot/samples/macros to current macros if it doesn't exist */
 
 #if defined(cygwin)
     if(dxmacros && *dxmacros)
@@ -428,12 +442,18 @@ int initrun()
 	strcat(dxmacros, "/");
     strcat(dxmacros,"samples/macros");
 #else
-    if(dxmacros && *dxmacros)
-	strcat(dxmacros, ";");
-    strcat(dxmacros, dxroot);
-    if(dxroot[strlen(dxroot)-1] !='\\')
-	strcat(dxmacros, "\\");
-    strcat(dxmacros,"samples\\macros");
+   {
+        namestr buf;
+        strcpy(buf, dxroot);
+        if(dxroot[strlen(dxroot)-1] !='\\')
+	    strcat(buf, "\\");
+        strcat(buf,"samples\\macros");
+        if(strstr(dxmacros, buf) == 0) {
+	    if(dxmacros && *dxmacros)
+                strcat(dxmacros, ";");
+            strcat(dxmacros, buf);
+        }
+    }
 #endif
 
     /* fill envargs */
@@ -653,7 +673,7 @@ void dxjsconfig() {
     sprintf(temp, "%s\\userdata", jdxsrvPath);
     ConvertShortPathName(temp);
     if(*dxdata)
-    	strcat(dxmacros, ";"); strcat(dxdata, temp);
+    	strcat(dxdata, ";"); strcat(dxdata, temp);
     setenvpair("DXDATA",	dxdata);
 
     setenvpair("DXMODULES",	dxmodules);
@@ -704,7 +724,6 @@ int buildcmd()
 			sprintf(dxexecdef, "%s\\bin_%s\\dxexec%s", dxexroot, exarch, EXE_EXT);
 		setifnot(dxexec, dxexecdef);
 		setifnot(exmode, "-r");
-		setifnot(exhilite, "-B");
 
 		setifnot(dxuiroot, dxroot);
 		if (notset(dxui))
@@ -1250,6 +1269,7 @@ int parseparms()
 	    neitheroff(timing);
 	next
 
+
 	is(highlight)
 	    lastoff(highlight)
 	    eqon
