@@ -110,11 +110,15 @@ int select(
 #include <io.h>
 #endif
 
-#if defined(intelnt)
+#if defined(macos)
+#include <crt_externs.h>
+#endif
+
+#if defined(intelnt) || defined(WIN32)
 HANDLE	hpipeRead, hpipeWrite;
 #endif
 
-#if !defined(intelnt) && !defined(OS2)
+#if !defined(intelnt) && !defined(OS2) && !defined(WIN32)
 #include <sys/wait.h>
 #else
 #ifdef DXD_WINSOCK_SOCKETS
@@ -128,11 +132,11 @@ HANDLE	hpipeRead, hpipeWrite;
 #endif
 #endif
 
-#ifndef HAS_HERROR
+#if !defined(HAS_HERROR) && !defined(herror)
 #    define herror perror
 #endif
 
-#if defined(intelnt)
+#if defined(intelnt) || defined(WIN32)
 HANDLE
 #else
 static int 
@@ -180,7 +184,7 @@ static int _dxl_ReadPortNumber(int fd)
 #endif
 #endif
 
-#if defined(intelnt)
+#if defined(intelnt) || defined(WIN32)
     DWORD dwRead, dwAvail, dwMess;
 #endif
     struct timeval to;
@@ -196,7 +200,7 @@ static int _dxl_ReadPortNumber(int fd)
     else
 	time_remaining = TIMEOUT;
 
-#if defined(intelnt)
+#if defined(intelnt) || defined(WIN32)
     time_remaining *= 1000;
 #endif
 
@@ -207,7 +211,7 @@ static int _dxl_ReadPortNumber(int fd)
 
 #if !defined(OS2)  && !defined(DXD_HAS_WINSOCKETS)
 	to.tv_sec = time_remaining;
-	n = select(width, (SELECT_ARG_TYPE *)&fds, NULL, NULL, &to); 
+	n = select(fd+1, (SELECT_ARG_TYPE *)&fds, NULL, NULL, &to); 
 	if (n <= 0)
 	{
             if (n < 0)
@@ -228,7 +232,7 @@ static int _dxl_ReadPortNumber(int fd)
 	}
 #endif
 
-#if defined(intelnt)
+#if defined(intelnt) || defined(WIN32)
 	i = PeekNamedPipe(hpipeRead, buf, (DWORD) sizeof(buf) -1, &dwRead, &dwAvail, &dwMess);
 	if(i == FALSE){
 	    Sleep(50);
@@ -265,7 +269,7 @@ static int _dxl_ReadPortNumber(int fd)
 	    }
        }
 
-#if !defined(intelnt)
+#if !defined(intelnt) && !defined(WIN32)
 	current_time = (long)time(NULL);
 	time_remaining = time_remaining - (current_time - start_time);
 	start_time = current_time;
@@ -281,19 +285,23 @@ static int _dxl_ReadPortNumber(int fd)
 static int
 DXLStartChild(const char *string, const char *host, int* inp, int* outp, int* errp)
 {
-    extern char **environ;
     int in, out, err;
     static char errorstr[256];
     char *argv[256];
     char  pi[256];
     int port;
-  #if defined(intelnt)
+  #if defined(intelnt) || defined(WIN32)
     HANDLE child;
   #else
     int child;
   #endif
     int i, n;
     char *c, *s;
+#if defined(macos)
+    char **environ = *_NSGetEnviron();
+#else
+    extern char **environ;
+#endif
 
     if (strstr(string,"-exonly")) {
 	char *s;
@@ -368,11 +376,7 @@ DXLStartChild(const char *string, const char *host, int* inp, int* outp, int* er
 
     free(s);
 
-#if !defined(intelnt)
-    if (child == NULL)
-#else
     if (child == 0)
-#endif
     {
 	fprintf(stderr, "DXLStartChild: %s\n", errorstr);
 	return -1;
@@ -387,7 +391,7 @@ DXLStartChild(const char *string, const char *host, int* inp, int* outp, int* er
 	    buf[n] = '\0';
 	    fprintf(stderr,buf);
 	}
-#if defined(intelnt)
+#if defined(intelnt) || defined(WIN32)
     TerminateProcess(child, -1);
 #else
 	kill(child, SIGKILL);
@@ -473,12 +477,11 @@ DXLConnection *
 DXLStartDX(const char *string, const char *host)
 {
     int port;
-    int fd;
     int in, out,err;
     DXLConnection *connection;
 
 
-#if  defined(DEBUG)  && defined(intelnt)
+#if  defined(DEBUG)  && (defined(intelnt) || defined(WIN32))
     /* This is to spawn DX seperately for debugging */
 
     if (!host && !getenv("DX_TEST_HOST") ) {
@@ -552,9 +555,6 @@ void _dxl_InvalidateSocket(DXLConnection *connection)
 void
 DXLCloseConnection(DXLConnection *connection)
 {
-    int i;
-    DXLEvent *e;
-
     if (connection->fd >= 0) {
 	close(connection->fd);
 	connection->fd = 0;
@@ -588,7 +588,7 @@ int DXLGetSocket(DXLConnection *connection)
     return connection->fd;
 }
 
-#if defined(intelnt)
+#if defined(intelnt) || defined(WIN32)
 HANDLE
 #else
 static int
@@ -605,10 +605,10 @@ ConnectTo(const char *host,
 		   char *errstr)
 {
     char s[BUFSIZ];
-    char wd[BUFSIZ],script_name[500],cmd[1000];
+    char script_name[500],cmd[1000];
     FILE *fp;
     int i;
-#if defined(intelnt) || defined(OS2)
+#if defined(intelnt) || defined(OS2) || defined(WIN32)
     int *in[2], *out[2], *err[2];
 #else
     int in[2], out[2], err[2];
@@ -617,11 +617,9 @@ ConnectTo(const char *host,
     char **fargv = NULL;
     int child;
     struct hostent *he;
-    char *home;
     int findx;
     char *pathEnv;
-    char *is;
-    char *os;
+    char *defaultPath = "PATH=/usr/bin:/usr/local/dx/bin";
     int  j;
 #ifdef hp700
     int  width = MAXFUPLIM;
@@ -674,10 +672,14 @@ ConnectTo(const char *host,
 	}
     }
 
-    for (pathEnv = NULL, i = 0; ep[i] && pathEnv == NULL; ++i)
-	if (    strncmp (ep[i], "PATH=", strlen("PATH=")) == 0 ||
-		strncmp (ep[i], "PATH =", strlen("PATH =")) == 0) 
-	    pathEnv = ep[i];
+    if(ep == NULL) {
+    	/* environment passed in was NULL */
+    	pathEnv = defaultPath;
+    } else
+        for (pathEnv = NULL, i = 0; ep[i] && pathEnv == NULL; ++i)
+	        if ( strncmp (ep[i], "PATH=", strlen("PATH=")) == 0 ||
+		         strncmp (ep[i], "PATH =", strlen("PATH =")) == 0) 
+	            pathEnv = ep[i];
 
     if (DXLIsHostLocal(host)) {
 	char *path;
@@ -824,7 +826,7 @@ ConnectTo(const char *host,
 			evar[j] = ep[i][j];
 		evar[j] = '\0';
 		k = j + 1;	/* Skip the '=' sign */
-		for (j=0 ; c = ep[i][k] ; k++, j++) {
+		for (j=0 ; (c = ep[i][k]) ; k++, j++) {
 			if (c == '\'') {		/* ' -> '\'' */
 				/* Value contains a double quote */
 				eval[j++] = '\'';
@@ -1029,7 +1031,7 @@ error_return:
 
 #endif    /*    OS2    */
 
-#ifdef	intelnt
+#if defined(intelnt) || defined(WIN32)
 
     char         args[1000];
     char         exename[255];
