@@ -16,6 +16,7 @@
 
 #include "IBMApplication.h"
 #include "List.h"
+#include "Dictionary.h"
 #include "DXExecCtl.h"
 #include "License.h"
 
@@ -24,6 +25,7 @@ class MsgWin;
 class ImageWindow;
 class ControlPanel;
 
+#define RECENT_NETS "recentNets"
 
 //
 // Class name definition:
@@ -200,6 +202,13 @@ typedef struct
     String	dxJarFile;
     String	userHtmlDir;
     String	serverDir;
+
+    //
+    // Automatic graph layout
+    //
+    int		autoLayoutHeight;
+    int		autoLayoutGroupSpacing;
+    int		autoLayoutNodeSpacing;
 } DXResource;
 
 
@@ -343,6 +352,8 @@ class DXApplication : public IBMApplication
     //
     static DXResource resource;	// resources and options
 
+    static String ListValuedSettings[];
+
     //
     // Protected member data:
     //
@@ -848,6 +859,10 @@ class DXApplication : public IBMApplication
 
     ApplicIF            *getAppConnection() { return this->applicationPacket; }
 
+    void appendReferencedFile (const char* file);
+    void removeReferencedFile (const char* file);
+    void getRecentNets(List& result);
+
 
     //
     // Returns a pointer to the class name.
