@@ -52,6 +52,7 @@ extern "C" void ImageWindow_RedrawCB(Widget, XtPointer, XtPointer);
 extern "C" void ImageWindow_WindowsMenuMapCB(Widget, XtPointer, XtPointer);
 extern "C" void ImageWindow_FileMenuMapCB(Widget, XtPointer, XtPointer);
 extern "C" Boolean ImageWindow_ResetEORWP(XtPointer);
+extern "C" void ImageWindow_ResizeTO (XtPointer , XtIntervalId* );
 
 //
 // Referenced classes:
@@ -223,7 +224,7 @@ struct ImageState {
 //				
 class ImageWindow : public DXWindow
 {
-    friend NoUndoImageCommand;
+    friend class NoUndoImageCommand;
 
   private:
     //
@@ -285,6 +286,7 @@ class ImageWindow : public DXWindow
 		      		  XtPointer clientData,
 		      		  XtPointer callData);
     friend Boolean ImageWindow_ResetEORWP(XtPointer);
+    friend void ImageWindow_ResizeTO (XtPointer , XtIntervalId* );
     boolean adjustDepth(int &depth);
 
     void completePictureCreation();
@@ -349,7 +351,7 @@ class ImageWindow : public DXWindow
 
 
 
-    virtual void resizeImage(XmPictureCallbackStruct*, Widget, boolean ok_to_send=TRUE);
+    virtual void resizeImage(boolean ok_to_send=TRUE);
     virtual void zoomImage(XmPictureCallbackStruct*);
     virtual void roamImage(XmPictureCallbackStruct*);
     virtual void rotateImage(XmPictureCallbackStruct*);
@@ -425,6 +427,7 @@ class ImageWindow : public DXWindow
     Command		*backgroundColorCmd;
     Command		*displayRotationGlobeCmd;
     Command             *openVPECmd;
+    CascadeMenu		*modeOptionCascade;
     CascadeMenu		*imageDepthCascade;
     Command             *imageDepth8Cmd;
     Command             *imageDepth12Cmd;
@@ -487,12 +490,24 @@ class ImageWindow : public DXWindow
     CommandInterface*	autoAxesOption;
     CommandInterface*	throttleOption;
     CommandInterface*	viewControlOption;
+    CommandInterface*	modeOption;
     CommandInterface*	undoOption;
     CommandInterface*	redoOption;
     CommandInterface*	resetOption;
     CommandInterface*	changeImageNameOption;
     CommandInterface*	backgroundColorOption;
     CommandInterface*	displayRotationGlobeOption;
+
+    ToggleButtonInterface*	modeNoneOption;
+    ToggleButtonInterface*	modeCameraOption;
+    ToggleButtonInterface*	modeCursorsOption;
+    ToggleButtonInterface*	modePickOption;
+    ToggleButtonInterface*	modeNavigateOption;
+    ToggleButtonInterface*	modePanZoomOption;
+    ToggleButtonInterface*	modeRoamOption;
+    ToggleButtonInterface*	modeRotateOption;
+    ToggleButtonInterface*	modeZoomOption;
+
     ToggleButtonInterface*	imageDepth8Option;
     ToggleButtonInterface*	imageDepth12Option;
     ToggleButtonInterface*	imageDepth15Option;
@@ -518,7 +533,7 @@ class ImageWindow : public DXWindow
     XtWorkProcId reset_eor_wp;
     int  pending_resize_x, pending_resize_y; 
     int  pending_resize_width, pending_resize_height;
-    static boolean ImageWindow::NeedsSyncForResize;
+    static boolean NeedsSyncForResize;
 
   protected:
 
@@ -584,6 +599,13 @@ class ImageWindow : public DXWindow
     //
     void configureImageDepthMenu();
 
+    //
+    // Set the state and sensitivity of the Mode cascade menu and its
+    // command interfaces.
+    //
+    void configureModeMenu();
+
+
     Node *getNodeByInstance(const char *classname, const char *name, 
 					int instance);
     
@@ -612,6 +634,14 @@ class ImageWindow : public DXWindow
     //virtual int displayWidth() { return 1280; }
     //virtual int displayHeight() { return 1024; }
 
+    //
+    // Rather than triggering an execution following a window resize,
+    // Queue the execution so that it happens soon after the execution
+    // but not immediately after.  This gives better results for users
+    // with window mgrs that deliver tons of resize events
+    //
+    XtIntervalId execute_after_resize_to;
+
 
   public:
     //
